==> imsdk-plus-6.9.3557-sources.jar: com/tencent/imsdk/message/MessageListGetOption.java <==
package com.tencent.imsdk.message;

import java.io.Serializable;
import java.util.List;

public class MessageListGetOption implements Serializable {
    private MessageKey messageKey;
    private boolean toOlderMessage;
    private boolean getCloudMessage;
    private int count;
    private long getTimeBegin;
    private long getTimePeriod;
    private List<Integer> messageTypeList;

    public MessageKey getMessageKey() {
        return messageKey;
    }

    public void setMessageKey(MessageKey messageKey) {
        this.messageKey = messageKey;
    }

    public boolean isToOlderMessage() {
        return toOlderMessage;
    }

    public void setToOlderMessage(boolean toOlderMessage) {
        this.toOlderMessage = toOlderMessage;
    }

    public boolean isGetCloudMessage() {
        return getCloudMessage;
    }

    public void setGetCloudMessage(boolean getCloudMessage) {
        this.getCloudMessage = getCloudMessage;
    }

    public int getCount() {
        return count;
    }

    public void setCount(int count) {
        this.count = count;
    }

    public long getGetTimeBegin() {
        return getTimeBegin;
    }

    public void setGetTimeBegin(long getTimeBegin) {
        this.getTimeBegin = getTimeBegin;
    }

    public long getGetTimePeriod() {
        return getTimePeriod;
    }

    public void setGetTimePeriod(long getTimePeriod) {
        this.getTimePeriod = getTimePeriod;
    }

    public void setMessageTypeList(List<Integer> messageTypeList) {
        this.messageTypeList = messageTypeList;
    }
}

==> imsdk-plus-7.9.5680-sources.jar: com/tencent/imsdk/message/MessageListGetOption.java <==
package com.tencent.imsdk.message;

import java.io.Serializable;
import java.util.List;

public class MessageListGetOption implements Serializable {
    private MessageKey messageKey;
    private boolean toOlderMessage;
    private boolean getCloudMessage;
    private int count;
    private long getTimeBegin;
    private long getTimePeriod;
    private List<Integer> messageTypeList;
    private List<Long> messageSequenceList;

    public MessageKey getMessageKey() {
        return messageKey;
    }

    public void setMessageKey(MessageKey messageKey) {
        this.messageKey = messageKey;
    }

    public boolean isToOlderMessage() {
        return toOlderMessage;
    }

    public void setToOlderMessage(boolean toOlderMessage) {
        this.toOlderMessage = toOlderMessage;
    }

    public boolean isGetCloudMessage() {
        return getCloudMessage;
    }

    public void setGetCloudMessage(boolean getCloudMessage) {
        this.getCloudMessage = getCloudMessage;
    }

    public int getCount() {
        return count;
    }

    public void setCount(int count) {
        this.count = count;
    }

    public long getGetTimeBegin() {
        return getTimeBegin;
    }

    public void setGetTimeBegin(long getTimeBegin) {
        this.getTimeBegin = getTimeBegin;
    }

    public long getGetTimePeriod() {
        return getTimePeriod;
    }

    public void setGetTimePeriod(long getTimePeriod) {
        this.getTimePeriod = getTimePeriod;
    }

    public void setMessageTypeList(List<Integer> messageTypeList) {
        this.messageTypeList = messageTypeList;
    }

    public void setMessageSequenceList(List<Long> messageSequenceList) {
        this.messageSequenceList = messageSequenceList;
    }
}
